@@ -82,6 +82,7 @@ describe 'keystone::ldap_backend' do
           :group_allow_update => 'False',
           :group_allow_delete => 'False',
           :group_additional_attribute_mapping => '',
+          :group_ad_nesting => 'True',
           :chase_referrals => 'False',
           :use_tls => 'False',
           :tls_cacertdir => '/etc/ssl/certs/',
@@ -176,6 +177,7 @@ describe 'keystone::ldap_backend' do
         is_expected.to contain_keystone_domain_config('Default::ldap/group_allow_update').with_value('False')
         is_expected.to contain_keystone_domain_config('Default::ldap/group_allow_delete').with_value('False')
         is_expected.to contain_keystone_domain_config('Default::ldap/group_additional_attribute_mapping').with_value('')
+        is_expected.to contain_keystone_domain_config('Default::ldap/group_ad_nesting').with_value('True')
 
         # referrals
         is_expected.to contain_keystone_domain_config('Default::ldap/chase_referrals').with_value('False')
